#ifndef _Z8536_h
#define _Z8536_h


/*----------------------------------------------------------------------
 * Main Control Registers
 *---------------------------------------------------------------------*/

#define	MIC_REG		0x0	/* Master Interrupt Control register */
#define	MCC_REG		0x1	/* Master Configuration Control register */
#define	IV_REG_A	0x2	/* PortA Interrupt Vector register */
#define	IV_REG_B	0x3	/* PortB Interrupt Vector register */
#define	IV_REG_CT	0x4	/* Counter Interrupt Vector register */
#define	DPP_REG_C	0x5	/* PortC Data Path Polarity register */
#define	DD_REG_C	0x6	/* PortC Data Direction register */
#define	SC_REG_C	0x7	/* PortC Special I/O Control register */


/*----------------------------------------------------------------------
 * Most often accessed registers
 *---------------------------------------------------------------------*/

#define	CS_REG_A	0x8	/* PortA Command and Status register */
#define	CS_REG_B 	0x9	/* PortB Command and Status register */
#define	CS_REG_CT1	0xa	/* Counter 1 Command and Status register */
#define	CS_REG_CT2	0xb	/* Counter 2 Command and Status register */
#define	CS_REG_CT3	0xc	/* Counter 3 Command and Status register */
#define	DATA_REG_A	0xd	/* PortA data register */
#define	DATA_REG_B	0xe	/* PortB data register */
#define	DATA_REG_C	0xf	/* PortC data register */


/*----------------------------------------------------------------------
 * Counter/Timer registers
 *---------------------------------------------------------------------*/

#define	CC_REG_CT1_MSB	0x10	/* Counter 1 Current Count register (MSB) */
#define	CC_REG_CT1_LSB	0x11	/* Counter 1 Current Count register (LSB) */
#define	CC_REG_CT2_MSB	0x12	/* Counter 2 Current Count register (MSB) */
#define	CC_REG_CT2_LSB	0x13	/* Counter 2 Current Count register (LSB) */
#define	CC_REG_CT3_MSB	0x14	/* Counter 3 Current Count register (MSB) */
#define	CC_REG_CT3_LSB	0x15	/* Counter 3 Current Count register (LSB) */
#define	TC_REG_CT1_MSB	0x16	/* Counter 1 Time Constant register (MSB) */
#define	TC_REG_CT1_LSB	0x17	/* Counter 1 Time Constant register (LSB) */
#define	TC_REG_CT2_MSB	0x18	/* Counter 2 Time Constant register (MSB) */
#define	TC_REG_CT2_LSB	0x19	/* Counter 2 Time Constant register (LSB) */
#define	TC_REG_CT3_MSB	0x1a	/* Counter 3 Time Constant register (MSB) */
#define	TC_REG_CT3_LSB	0x1b	/* Counter 3 Time Constant register (LSB) */
#define	MS_REG_CT1	0x1c	/* Counter 1 Mode Specification register */
#define	MS_REG_CT2	0x1d	/* Counter 2 Mode Specification register */
#define	MS_REG_CT3	0x1e	/* Counter 3 Mode Specification register */
#define	CV_REG		0x1f	/* Current vector register */


/*----------------------------------------------------------------------
 * Port A specification registers
 *---------------------------------------------------------------------*/

#define	MS_REG_A	0x20	/* Port A Mode Specification register */
#define	HS_REG_A	0x21	/* Port A Handshacke Specification register */
#define	DPP_REG_A	0x22	/* Port A Data Path Polarity register */
#define	DD_REG_A	0x23	/* Port A Data Direction register */
#define	SC_REG_A	0x24	/* Port A Special I/O Control register */
#define	PP_REG_A	0x25	/* Port A Pattern Polarity register */
#define	PT_REG_A	0x26	/* Port A Pattern Transition register */
#define	PM_REG_A	0x27	/* Port A Pattern Mask register */


/*----------------------------------------------------------------------
 * Port B specification registers
 *---------------------------------------------------------------------*/

#define	MS_REG_B	0x28	/* Port B Mode Specification register */
#define	HS_REG_B	0x29	/* Port B Handshacke Specification register */
#define	DPP_REG_B	0x2a	/* Port B Data Path Polarity register */
#define	DD_REG_B	0x2b	/* Port B Data Direction register */
#define	SC_REG_B	0x2c	/* Port B Special I/O Control register */
#define	PP_REG_B	0x2d	/* Port B Pattern Polarity register */
#define	PT_REG_B	0x2e	/* Port B Pattern Transition register */
#define	PM_REG_B	0x2f	/* Port B Pattern Mask register */


#endif /* _Z8536_h */
