/* VMEchip2.c */


#include <linux/kernel.h>
#include <linux/errno.h>

#include "VMEchip2.h"



/*----------------------------------------------------------------------
 * Macros 
 *---------------------------------------------------------------------*/

/*#define DEBUG*/

#ifdef DEBUG
#	define debug(x) printk x
#else
#	define debug(x)
#endif



/*----------------------------------------------------------------------
 * Function: VMEchip2_status()
 *
 * Print the content of parameters registers of the VMEchip2 from the
 * MVME16x board
 *---------------------------------------------------------------------*/

void VMEchip2_status (VMEchip2_addr)
unsigned long *VMEchip2_addr;
{
	int i;

	printk("  -VMEchip2 status (VMEchip2 address = 0x%p)\n",VMEchip2_addr);
	for(i=0;i<9;i++)
		printk("\t%04d : %08lX %08lX %08lX %08lX\n", 10*i,
*(VMEchip2_addr+4*i), *(VMEchip2_addr+4*i+1), *(VMEchip2_addr+4*i+2),
*(VMEchip2_addr+4*i+3));
}



/*----------------------------------------------------------------------
 * Function: VMEchip2_check_params()
 *
 * Check if the kind of window specified by the module parameters already
 * exist
 *---------------------------------------------------------------------*/

int VMEchip2_check_params (VMEchip2_addr, addr_mod, io_addr, segt_size)
u32 *VMEchip2_addr;
int addr_mod;
u32 *io_addr;
u32 segt_size;
{
	VMEchip2 *chip2 = (VMEchip2 *) VMEchip2_addr;
	int i;

	for (i=0; i<4; i++)
	{	
		debug(("  -Check Segment %d\n",i));

	/*
	 * Check if one of the 4 master windows has the good address modifier
	 */
		if ( ((chip2->master_adr_mod>>(8*i))&AM_MASK) == addr_mod )
		{
			u32 seg = chip2->master_adr[i];

			debug(("\t.Address Modifier OK\n"));

		/*
		 * Then, check if the found segment is wide enough
		 */
			if ( (((seg>>16)-(seg&0xFFFF))<<16) >= segt_size )
			{
				debug(("\t.Segment Size OK\n"));

			/*
			 * Then, check if the address space of the board goes
			 * in the window
			 */
				if ( (int)(io_addr+8) <= (seg|0x0000FFFF) )
				{
					debug(("\t.IO Address OK\n"));
					return 0;
				}
				else
				{
					debug(("\t.Not enough memory in the segment\n"));
				}
			}
			else
			{
				debug(("\t.Segment size don't fit\n"));
			}
		}
		else
		{
			debug(("\t.Bad Address Modifier\n"));
		}
	}
	printk("  -ERROR : Bad loading parameters\n");
	return -EINVAL;
}



/*----------------------------------------------------------------------
 * Function: VMEchip2_irq()
 *
 * CONFIG : Configure the 'irq' VMEchip2's IRQ with a standard IRQ level.
 * ENABLE : Set the 'irq' VMEchip2's IRQ enable.
 * DISABLE : Set the 'irq' VMEchip2's IRQ disable.
 *---------------------------------------------------------------------*/

int VMEchip2_irq (VMEchip2_addr, cmd, irq)
u32 *VMEchip2_addr;
u8 cmd;
u8 irq;
{
	u32 v;
	VMEchip2 *chip2 = (VMEchip2 *) VMEchip2_addr;

	debug(("  -VMEchip2_irq() :\n"));

	if (irq<=0 || irq >7)
	{
		debug(("\t.Bad VME IRQ request : must be from 1 to 7\n"));
		return -EINVAL;
	}
	
	switch (cmd)
	{
	case CONFIG:
		v = chip2->it_level_vmeirq & ~(IRQLVL_MASK << (irq-1)*4);
		chip2->it_level_vmeirq = v | ((irq & IRQLVL_MASK) << (irq-1)*4);

		debug(("\t.VME IRQ %d has been set with the m68k level %d on VMEchip2\n", irq, irq));
		return 0;

	case ENABLE:
		chip2->it_enable |= (1 << (irq-1));

		debug(("\t.VME IRQ %d has been enabled on VMEchip2\n", irq));
		return 0;

	case DISABLE:
		chip2->it_enable &= ~(1 << (irq-1));

		debug(("\t.VME IRQ %d has been disabled on VMEchip2\n", irq));
		return 0;

/*
 * We don't need that for now
 *
	case ENABLE_ALL:
		chip2->it_enable |= IRQEN_MASK;

		debug(("\t.All VME IRQ has been enabled on VMEchip2\n"));
		return 0;

	case DISABLE_ALL:
		chip2->it_enable &= ~IRQEN_MASK;

		debug(("\t.All VME IRQ has been disabled on VMEchip2\n"));
		return 0;
 */

	default:
		debug(("\t\t+Bad VMEchip2_irq command\n"));
		return -EINVAL;
	}
}
