#include <stdio.h>
#include <errno.h>
#include <sys/ioctl.h>
#include <sys/file.h>
#include <sys/time.h>
#include <unistd.h>
#include "ICV196.h"

/*
 * squarewave.c - program to try to reproduce a square wave provided as input on
 *                one bit of an ICV196 on an output bit of the ICV196. This is a
 *                very simple test of performance i.e. what is the maximum frequency
 *                at which the program can still reproduce the square wave and
 *                what is the maximum delay in reprodcing the square wave.
 *
 *                This program is also a test of the ICV196 device driver
 *
 * author       - andy gotz
 *
 * date         - 23/8/99
 */
	
extern int errno;

void main (unsigned int argc, char **argv)
{
        int fd, i, j;
        ICV196_arg arg;
	int in=0, out=95, edge[2] = {RISE, FALL}, value[2] = {0, 1};
	struct timeval before, after;
	struct timespec millisec={0, 100000};
	float elapsed;
	int action;

	if (argc > 1) {
        	fd = open (argv[1], O_RDWR, 0x666); 
		printf("opened %s , fd=%d\n",argv[1],fd);
	}
	else {
        	fd = open ("/dev/ICV196_0", O_RDWR, 0x666); 
		printf("opened /dev/ICV196_0 , fd=%d\n",fd);
	}
	if (argc > 2) {
        	sscanf(argv[2],"%d",&in);
		if ((in < 0) || (in > 15)) in = 0;
	}
	if (argc > 3) {
        	sscanf(argv[2],"%d",&out);
		if ((out < 48) || (out > 95)) out = 95;
	}
	printf("squarewave - copy a square wave from input channel %d to output channel %d\n",
	        in,out);

/*
 * program first 6 groups (12 bytes) as inputs and last 2 groups as outputs
 */
	arg.op = IO_DIR;
	arg.val[0] = 0xc0;
	arg.val[1] = 0x0f;
	if (ioctl(fd, WR, (void*)&arg) != 0)
        {
	        printf("error detected programming direction (errno = %d) !\n",errno);
        }            

	for (;;)
	{
		gettimeofday(&before, NULL);
		for (i=0; i<2; i++)
		{
			arg.num = in;
			arg.it_edge = edge[i];
			arg.it_timeout = 0;
			if (ioctl(fd, SLEEP, (void*)&arg) != 0)
			{
				printf("error detected waiting for sleep (errno = %d) !\n",errno);
			}
/*
 * toggle output bit
 */
			arg.op = DIO_BIT;
			arg.num = out;
			arg.val[0] = value[i];
			if (ioctl(fd, WR, (void*)&arg) != 0)
			{
				printf("error detected writing (errno = %d) !\n",errno);
			}
		}
		gettimeofday(&after, NULL);
		elapsed = after.tv_sec - before.tv_sec;
		elapsed = elapsed*1000. + (float)(after.tv_usec-before.tv_usec)/1000.;
		printf("elapsed time %6.3f ms for 1 square wave cycle\n",
		       	elapsed);
	}
}

